SResizableMenuNoWrapper class

Inheritance

Constructors

SResizableMenuNoWrapper({Key? key, SMenuStyle? style = const SMenuStyle(), SMenuController? controller, List<SMenuItem>? items, Widget builder(BuildContext context)?, Widget? header, Widget? footer, ScrollPhysics? scrollPhysics, Axis? direction = Axis.vertical, Duration? duration = const Duration(milliseconds: 250), SMenuPosition? position = SMenuPosition.left, bool? enableSelector = false, bool? resizable = true, Color? barColor, Color? barHoverColor, double? barSize, double? barHoverSize})
const

Properties

barColor Color?
final
barHoverColor Color?
final
barHoverSize double?
final
barSize double?
final
builder Widget Function(BuildContext context)?
finalinherited
controller SMenuController?
finalinherited
direction Axis?
finalinherited
duration Duration?
finalinherited
enableSelector bool?
final
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
items List<SMenuItem>?
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
position SMenuPosition?
finalinherited
resizable bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics ScrollPhysics?
finalinherited
style SMenuStyle?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SResizableMenuNoWrapper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited