SMenuStyle class
Constructors
- SMenuStyle({Color? barColor, Color? backgroundColor, BoxConstraints? size, BoxBorder? border, EdgeInsets? padding, BorderRadius? borderRadius, MainAxisAlignment? headerAlignment, MainAxisAlignment? alignment})
-
const
Properties
- alignment → MainAxisAlignment?
-
final
- backgroundColor → Color?
-
final
- barColor → Color?
-
final
- border → BoxBorder?
-
final
- borderRadius → BorderRadius?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerAlignment → MainAxisAlignment?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → BoxConstraints?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited